---
label: Waveclus
dockerfile: 
wrapper: https://github.com/flatironinstitute/spikeforest/blob/master/spikeforest/spikesorters/waveclus/waveclus.py
website: https://github.com/csn-le/wave_clus/wiki
source_code: https://github.com/csn-le/wave_clus
authors: F. J. Chaure, H. G. Rey and R. Quian Quiroga
processor_name: Waveclus
doi: 10.1152/jn.00339.2018
---
_
# Waveclus

## Description

Wave_clus is a fast and unsupervised algorithm for spike detection and sorting that runs under Windows, Mac or Linux operating systems.

To install, download this repository into a folder. In MATLAB (R2009b or higher) go to Set Path and add the directory wave_clus with subfolders to the MATLAB path.


## References

[1] A novel and fully automatic spike sorting implementation with variable number of features. F. J. Chaure, H. G. Rey and R. Quian Quiroga. Journal of Neurophysiology; 2018. https://doi.org/10.1152/jn.00339.2018

[2] Quian Quiroga R, Nadasdy Z, Ben-Shaul Y. Unsupervised spike detection and sorting with wavelets and superparamagnetic clustering. Neural Comput 16: 1661–1687, 2004. doi:10.1162/089976604774201631. 